# Rust
noblacklist ${HOME}/.cargo/config
noblacklist ${HOME}/.cargo/registry

# Git
noblacklist ${HOME}/.config/git
noblacklist ${HOME}/.gitconfig
noblacklist ${HOME}/.git-credentials

# Python
noblacklist ${HOME}/.python-history
noblacklist ${HOME}/.python_history
noblacklist ${HOME}/.pythonhist

# Java
noblacklist ${HOME}/.gradle
noblacklist ${HOME}/.java
